@@ -39,4 +39,7 @@ sub _build_element_name {
     return 'join';
 }
 
+__PACKAGE__->meta->make_immutable;
+no Moose;
+
 1;
